The Bader Calculator
--------------------

Bader Chager Analysis (or "Bader" for short) is a process of  partitioning charge density in order to predict oxidation states. This module is specifically for the [Henkelman Group](http://theory.cm.utexas.edu/henkelman/)'s code that implements this analysis. 

The code is free to everyone and can be downloaded [here](http://theory.cm.utexas.edu/henkelman/code/bader/).


## Helpful links

 - [website](http://theory.cm.utexas.edu/henkelman/code/bader/) (includes docs + guide)
